@@ -1,5 +1,4 @@
 from django import forms
-from django.conf.urls import url as urls_url
 from django.contrib import admin, messages
 from django.contrib.admin.templatetags.admin_list import _boolean_icon
 from django.contrib.admin.utils import unquote
@@ -8,8 +7,7 @@ from django.contrib.staticfiles.templatetags.staticfiles import static
 from django.core.exceptions import ValidationError
 from django.db.models import BooleanField, Func
 from django.db.models.expressions import Random
-from django.http import HttpResponse, HttpResponseRedirect
-from django.shortcuts import get_object_or_404, render
+from django.http import HttpResponseRedirect
 from django.urls import reverse
 from django.utils.formats import date_format
 from django.utils.html import format_html
@@ -36,6 +34,7 @@ from ..models.subjects import (
     SubjectRegistrationGroupMember,
     SubjectRegistrationParticipant,
     SubjectReturnedPayment,
+    SubjectTime,
     SubjectType,
     SubjectTypeAttachment,
     SubjectVariant,
@@ -114,6 +113,11 @@ class SubjectAttachmentInlineAdmin(admin.TabularInline):
     extra = 0
 
 
+class SubjectTimeInlineAdmin(admin.TabularInline):
+    model = SubjectTime
+    extra = 0
+
+
 class SubjectVariantInlineAdmin(admin.TabularInline):
     model = SubjectVariant
     extra = 0
@@ -132,6 +136,7 @@ class SubjectBaseAdmin(AdminExportMixin, BulkUpdateMixin, SendMessageAdminMixin,
     )
     inlines = (
         SubjectVariantInlineAdmin,
+        SubjectTimeInlineAdmin,
         SubjectAttachmentInlineAdmin,
     )
     filter_horizontal = ("age_groups", "target_groups", "groups", "leaders", "questions", "registration_agreements")
@@ -256,26 +261,21 @@ class SubjectBaseAdmin(AdminExportMixin, BulkUpdateMixin, SendMessageAdminMixin,
         obj.school_year = request.school_year
         return obj
 
-    def get_journal_link(self, obj):
-        return "<br/>".join(
-            (
-                format_html(
-                    '<a href="{url}" title="{title}" target="_blank">{journal}</a>',
-                    url=reverse("admin:leprikon_subject_journal", args=[obj.id]),
-                    title=_("printable journal"),
-                    journal=_("journal"),
-                ),
-                format_html(
-                    '<a href="{url}" title="{title}" target="_blank">{participants}</a>',
-                    url=reverse("admin:leprikon_subject_journal_pdf", args=[obj.id]),
-                    title=_("printable list of participants"),
-                    participants=_("participants"),
-                ),
-            )
+    def journals_link(self, obj):
+        return format_html(
+            '<a href="{url}">{journals}</a>',
+            url=reverse("admin:leprikon_journal_changelist")
+            + f"?subject__subject_type__id__exact={obj.subject_type_id}&subject__id__exact={obj.id}",
+            journals=_("journals"),
+        ) + format_html(
+            '<a href="{url}" style="background-position: 0 0" title="{title}">' '<img src="{icon}" alt="+"/></a>',
+            url=reverse("admin:leprikon_journal_add") + "?subject={}".format(obj.id),
+            title=_("add journal"),
+            icon=static("admin/img/icon-addlink.svg"),
         )
 
-    get_journal_link.short_description = _("journal")
-    get_journal_link.allow_tags = True
+    journals_link.short_description = _("journal")
+    journals_link.allow_tags = True
 
     def get_message_recipients(self, request, queryset):
         return get_user_model().objects.filter(leprikon_subjectregistrations__subject__in=queryset).distinct()
@@ -399,40 +399,6 @@ class SubjectAdmin(AdminExportMixin, SendMessageAdminMixin, ChangeformRedirectMi
     icon.allow_tags = True
     icon.short_description = _("photo")
 
-    def get_urls(self):
-        return [
-            urls_url(
-                r"(?P<subject_id>\d+)/journal/$",
-                self.admin_site.admin_view(self.journal),
-                name="leprikon_subject_journal",
-            ),
-            urls_url(
-                r"(?P<subject_id>\d+)/journal-pdf/$",
-                self.admin_site.admin_view(self.journal_pdf),
-                name="leprikon_subject_journal_pdf",
-            ),
-        ] + super().get_urls()
-
-    def journal(self, request, subject_id):
-        return render(
-            request,
-            "leprikon/subject_journal.html",
-            {
-                "subject": get_object_or_404(Subject, id=subject_id),
-                "admin": True,
-            },
-        )
-
-    def journal_pdf(self, request, subject_id):
-        obj = self.get_object(request, subject_id)
-
-        # create PDF response object
-        response = HttpResponse(content_type="application/pdf")
-        response["Content-Disposition"] = 'attachment; filename="{}"'.format(obj.get_pdf_filename("journal_pdf"))
-
-        # write PDF to response
-        return obj.write_pdf("journal_pdf", response)
-
 
 class SubjectRegistrationParticipantInlineAdmin(admin.StackedInline):
     model = SubjectRegistrationParticipant
@@ -486,8 +452,28 @@ class RegistrationBillingInfoInlineAdmin(admin.TabularInline):
 
 
 class SubjectRegistrationBaseAdmin(AdminExportMixin, SendMailAdminMixin, SendMessageAdminMixin, admin.ModelAdmin):
+    actions = ("approve", "refuse", "request_payment", "offer_refund", "generate_refund_request", "cancel")
     form = RegistrationAdminForm
     inlines = (RegistrationBillingInfoInlineAdmin,)
+    list_display = (
+        "variable_symbol",
+        "download_tag",
+        "subject_name",
+        "participants_list_html",
+        "price",
+        "discounts",
+        "total_price",
+        "received_payments",
+        "returned_payments",
+        "created_with_by",
+        "approved_with_by",
+        "payment_requested_with_by",
+        "refund_offered_with_by",
+        "cancelation_requested_with_by",
+        "canceled_with_by",
+        "note",
+        "random_number",
+    )
     list_editable = ("note",)
     list_export = (
         "id",
@@ -582,7 +568,6 @@ class SubjectRegistrationBaseAdmin(AdminExportMixin, SendMailAdminMixin, SendMes
         ("subject__leaders", LeaderListFilter),
         "subject__place",
     )
-    actions = ("approve", "refuse", "request_payment", "offer_refund", "cancel")
     search_fields = (
         "variable_symbol",
         "participants__birth_num",
@@ -609,7 +594,7 @@ class SubjectRegistrationBaseAdmin(AdminExportMixin, SendMailAdminMixin, SendMes
         return m
 
     def has_delete_permission(self, request, obj=None):
-        if obj and obj.approved is None and obj.payments.count() == 0 and obj.returned_payments.count() == 0:
+        if obj and obj.approved is None and obj.received_payments.count() == 0 and obj.returned_payments.count() == 0:
             return super().has_delete_permission(request, obj)
         else:
             return False
@@ -643,7 +628,7 @@ class SubjectRegistrationBaseAdmin(AdminExportMixin, SendMailAdminMixin, SendMes
             .get_queryset(request)
             .prefetch_related(
                 "discounts",
-                "payments",
+                "received_payments",
                 "returned_payments",
             )
             .select_related(
@@ -695,6 +680,13 @@ class SubjectRegistrationBaseAdmin(AdminExportMixin, SendMailAdminMixin, SendMes
 
     offer_refund.short_description = _("Offer refund for selected registrations")
 
+    def generate_refund_request(self, request, queryset):
+        for registration in queryset.filter(refund_request__bank_account=None):
+            registration.generate_refund_request(request.user)
+        self.message_user(request, _("Refund requests were generated for selected registrations."))
+
+    generate_refund_request.short_description = _("Generate refund requests for selected registrations")
+
     def cancel(self, request, queryset):
         for registration in queryset.all():
             try:
@@ -836,22 +828,43 @@ class SubjectRegistrationBaseAdmin(AdminExportMixin, SendMailAdminMixin, SendMes
     random_number.admin_order_field = "random_number"
     random_number.short_description = _("random number")
 
-    def returned_payments(self, obj):
+    def received_payments(self, obj: SubjectRegistration):
         return format_html(
-            '<a href="{href}"><b>{amount}</b></a>',
-            href=reverse("admin:leprikon_subjectreturnedpayment_changelist") + f"?source_registration={obj.id}",
-            amount=currency(sum(r.amount for r in obj.all_returned_payments)),
-        ) + format_html(
-            '<a class="popup-link" href="{href}" style="background-position: 0 0" title="{title}">'
-            '<img src="{icon}" alt="+"/></a>',
-            href=reverse("admin:leprikon_subjectreturnedpayment_add") + f"?source_registration={obj.id}",
-            title=_("add returned payment"),
-            icon=static("admin/img/icon-addlink.svg"),
+            '<a style="color: {color}" href="{href_list}" title="{title}"><b>{amount}</b></a>'
+            ' &nbsp; <a class="popup-link" href="{href_add}" style="background-position: 0 0" title="{title_add}">'
+            '<img src="{icon_add}" alt="+"/></a>',
+            amount=currency(obj.payment_status.received),
+            color=obj.payment_status.color,
+            href_add=reverse("admin:leprikon_subjectreceivedpayment_add") + f"?target_registration={obj.id}",
+            href_list=reverse("admin:leprikon_subjectreceivedpayment_changelist") + f"?target_registration={obj.id}",
+            icon_add=static("admin/img/icon-addlink.svg"),
+            title=obj.payment_status.title,
+            title_add=_("add received payment"),
+        )
+
+    received_payments.allow_tags = True
+    received_payments.short_description = _("received payments")
+
+    def returned_payments(self, obj: SubjectRegistration):
+        return format_html(
+            '<a href="{href_list}"><b>{amount}</b></a>'
+            ' &nbsp; <a class="popup-link" href="{href_add}" style="background-position: 0 0" title="{title_add}">'
+            '<img src="{icon_add}" alt="+"/></a>',
+            amount=currency(obj.payment_status.returned),
+            href_add=reverse("admin:leprikon_subjectreturnedpayment_add") + f"?source_registration={obj.id}",
+            href_list=reverse("admin:leprikon_subjectreturnedpayment_changelist") + f"?source_registration={obj.id}",
+            icon_add=static("admin/img/icon-addlink.svg"),
+            title_add=_("add returned payment"),
         )
 
     returned_payments.allow_tags = True
     returned_payments.short_description = _("returned payments")
 
+    def total_price(self, obj: SubjectRegistration):
+        return currency(obj.payment_status.receivable)
+
+    total_price.short_description = _("total price")
+
 
 @admin.register(SubjectRegistration)
 class SubjectRegistrationAdmin(AdminExportMixin, SendMessageAdminMixin, ChangeformRedirectMixin, admin.ModelAdmin):
