@@ -1,20 +1,17 @@
 from collections import namedtuple
-from datetime import date, datetime, timedelta
+from datetime import date, timedelta
+from typing import List
 
 from cms.models import CMSPlugin
 from django.db import models, transaction
 from django.dispatch import receiver
-from django.utils.encoding import force_text
 from django.utils.formats import date_format
 from django.utils.functional import cached_property
 from django.utils.translation import ugettext_lazy as _
 
 from ..conf import settings
-from ..utils import comma_separated
 from .agegroup import AgeGroup
 from .department import Department
-from .fields import DAY_OF_WEEK, DayOfWeekField
-from .journals import JournalEntry
 from .roles import Leader
 from .schoolyear import SchoolYear, SchoolYearDivision, SchoolYearPeriod
 from .startend import StartEndMixin
@@ -39,10 +36,6 @@ class Course(Subject):
         verbose_name = _("course")
         verbose_name_plural = _("courses")
 
-    @cached_property
-    def all_times(self):
-        return list(self.times.all())
-
     @cached_property
     def all_periods(self):
         return list(self.school_year_division.periods.all())
@@ -51,17 +44,6 @@ class Course(Subject):
     def all_journal_entries(self):
         return list(self.journal_entries.all())
 
-    def get_times_list(self):
-        return comma_separated(self.all_times)
-
-    get_times_list.short_description = _("times")
-
-    def get_next_time(self, now=None):
-        try:
-            return min(t.get_next_time(now) for t in self.all_times)
-        except ValueError:
-            return None
-
     @property
     def registrations_history_registrations(self):
         return CourseRegistration.objects.filter(course_history__course=self).distinct()
@@ -104,55 +86,6 @@ class Course(Subject):
         return new
 
 
-class CourseTime(StartEndMixin, models.Model):
-    course = models.ForeignKey(Course, on_delete=models.CASCADE, related_name="times", verbose_name=_("course"))
-    day_of_week = DayOfWeekField(_("day of week"))
-    start = models.TimeField(_("start time"), blank=True, null=True)
-    end = models.TimeField(_("end time"), blank=True, null=True)
-
-    class Meta:
-        app_label = "leprikon"
-        ordering = ("day_of_week", "start")
-        verbose_name = _("time")
-        verbose_name_plural = _("times")
-
-    def __str__(self):
-        if self.start is not None and self.end is not None:
-            return _("{day}, {start:%H:%M} - {end:%H:%M}").format(
-                day=self.day,
-                start=self.start,
-                end=self.end,
-            )
-        elif self.start is not None:
-            return _("{day}, {start:%H:%M}").format(
-                day=self.day,
-                start=self.start,
-            )
-        else:
-            return force_text(self.day)
-
-    @cached_property
-    def day(self):
-        return DAY_OF_WEEK[self.day_of_week]
-
-    Time = namedtuple("Time", ("date", "start", "end"))
-
-    def get_next_time(self, now=None):
-        now = now or datetime.now()
-        daydelta = (self.day_of_week - now.isoweekday()) % 7
-        if daydelta == 0 and (isinstance(now, date) or self.start is None or self.start <= now.time()):
-            daydelta = 7
-        if isinstance(now, datetime):
-            next_date = now.date() + timedelta(daydelta)
-        else:
-            next_date = now + timedelta(daydelta)
-        return self.Time(
-            date=next_date,
-            start=self.start,
-            end=self.end,
-        )
-
-
 class CourseRegistration(SubjectRegistration):
     subject_type = SubjectType.COURSE
 
@@ -162,19 +95,23 @@ class CourseRegistration(SubjectRegistration):
         verbose_name_plural = _("course registrations")
 
     @cached_property
-    def all_registration_periods(self):
+    def all_registration_periods(self) -> List["CourseRegistrationPeriod"]:
         return list(self.course_registration_periods.select_related("period"))
 
     def get_period_payment_statuses(self, d=None):
-        paid = self.get_paid(d)
+        received = self.get_received(d)
+        returned = self.get_returned(d)
+
         for counter, registration_period in enumerate(self.all_registration_periods, start=1):
             period_payment_status = registration_period.get_payment_status(
-                paid=paid,
+                received=received,
+                returned=returned,
                 last_period=counter == len(self.all_registration_periods),
                 d=d,
             )
             yield period_payment_status
-            paid -= period_payment_status.status.paid
+            received -= period_payment_status.status.received
+            returned = 0  # all returned payments are "spent" to the first period
         if not self.all_registration_periods:
             # create fake registration period to ensure some payment status
             registration_period = CourseRegistrationPeriod(
@@ -190,7 +127,8 @@ class CourseRegistration(SubjectRegistration):
                     price=0,
                     discount=0,
                     explanation="",
-                    paid=paid,
+                    received=received,
+                    returned=returned,
                     current_date=d,
                     due_from=None,
                     due_date=None,
@@ -242,12 +180,17 @@ class CourseRegistrationPeriod(models.Model):
         # return list(self.discounts.all())
         return [discount for discount in self.registration.all_discounts if discount.registration_period_id == self.id]
 
-    PeriodPaymentStatus = namedtuple(
-        "PeriodPaymentStatus",
-        ("period", "registration_period", "status"),
-    )
+    class PeriodPaymentStatus(
+        namedtuple(
+            "PeriodPaymentStatus",
+            ["period", "registration_period", "status"],
+        )
+    ):
+        period: SchoolYearPeriod
+        registration_period: "CourseRegistrationPeriod"
+        status: PaymentStatus
 
-    def get_payment_status(self, paid, last_period, d=None):
+    def get_payment_status(self, received, returned, last_period, d=None) -> PeriodPaymentStatus:
         if d is None:
             d = date.today()
         discount = sum(discount.amount for discount in self.all_discounts if discount.accounted.date() <= d)
@@ -263,7 +206,8 @@ class CourseRegistrationPeriod(models.Model):
                 price=self.registration.price,
                 discount=discount,
                 explanation=explanation,
-                paid=min(self.registration.price - discount, paid) if not last_period else paid,
+                received=min(self.registration.price - discount + returned, received) if not last_period else received,
+                returned=returned,
                 current_date=d,
                 due_from=self.registration.payment_requested
                 and max(
@@ -332,14 +276,6 @@ class CourseRegistrationHistory(StartEndMixin, models.Model):
             end=date_format(self.end, "SHORT_DATE_FORMAT") if self.end else _("now"),
         )
 
-    @property
-    def journal_entries(self):
-        qs = JournalEntry.objects.filter(subject_id=self.course_id, date__gte=self.start)
-        if self.end:
-            return qs.filter(date__lte=self.end)
-        else:
-            return qs
-
     def save(self, *args, **kwargs):
         if self.id:
             original = self.__class__.objects.get(id=self.id)
