@@ -46,8 +46,9 @@ from .roles import Leader
 from .school import School
 from .schoolyear import SchoolYear
 from .targetgroup import TargetGroup
+from .times import AbstractTime, TimesMixin
 from .transaction import AbstractTransaction, Transaction
-from .utils import PaymentStatus, generate_variable_symbol, lazy_help_text_with_html_default, shorten
+from .utils import BankAccount, PaymentStatus, generate_variable_symbol, lazy_help_text_with_html_default
 
 logger = logging.getLogger(__name__)
 
@@ -253,6 +254,10 @@ class SubjectType(models.Model):
     def get_absolute_url(self):
         return reverse(self.slug + ":subject_list")
 
+    def get_journals_url(self):
+        change_list = reverse("admin:leprikon_journal_changelist")
+        return f"{change_list}?subject__subject_type__id__exact={self.id}"
+
     def get_subjects_url(self):
         change_list = reverse(f"admin:leprikon_{self.subject_type}_changelist")
         return f"{change_list}?subject_type__id__exact={self.id}"
@@ -265,7 +270,7 @@ class SubjectType(models.Model):
         change_list = reverse(f"admin:leprikon_{self.subject_type}discount_changelist")
         return f"{change_list}?registration__subject__subject_type__id__exact={self.id}"
 
-    def get_payments_url(self):
+    def get_received_payments_url(self):
         change_list = reverse("admin:leprikon_subjectreceivedpayment_changelist")
         return f"{change_list}?target_registration__subject__subject_type__id__exact={self.id}"
 
@@ -354,7 +359,7 @@ class SubjectGroup(models.Model):
         )
 
 
-class Subject(PdfExportAndMailMixin, models.Model):
+class Subject(TimesMixin, models.Model):
     PARTICIPANTS = "P"
     GROUPS = "G"
     REGISTRATION_TYPE_CHOICES = [
@@ -415,9 +420,6 @@ class Subject(PdfExportAndMailMixin, models.Model):
     min_registrations_count = models.PositiveIntegerField(_("minimal registrations count"), blank=True, null=True)
     max_registrations_count = models.PositiveIntegerField(_("maximal registrations count"), blank=True, null=True)
     min_due_date_days = models.PositiveIntegerField(_("minimal number of days to due date"), default=3)
-    risks = HTMLField(_("risks"), blank=True)
-    plan = HTMLField(_("plan"), blank=True)
-    evaluation = HTMLField(_("evaluation"), blank=True)
     note = models.CharField(_("note"), max_length=300, blank=True, default="")
     questions = models.ManyToManyField(
         Question,
@@ -516,10 +518,6 @@ class Subject(PdfExportAndMailMixin, models.Model):
     def registration_type_groups(self):
         return self.registration_type == self.GROUPS
 
-    @cached_property
-    def slug(self):
-        return shorten(slugify(self), 100)
-
     @cached_property
     def subject(self):
         if self.subject_type.subject_type == self.subject_type.COURSE:
@@ -572,38 +570,6 @@ class Subject(PdfExportAndMailMixin, models.Model):
     def all_registrations(self):
         return list(self.registrations.all())
 
-    def get_valid_participants(self, d):
-        qs = SubjectRegistrationParticipant.objects
-        if self.subject_type.subject_type == SubjectType.COURSE:
-            qs = qs.filter(
-                models.Q(registration__courseregistration__course_history__course_id=self.id)
-                & (
-                    models.Q(registration__courseregistration__course_history__end__isnull=True)
-                    | models.Q(registration__courseregistration__course_history__end__gte=d)
-                )
-            )
-        else:  # self.subject_type.subject_type in (SubjectType.EVENT, SubjectType.ORDERABLE):
-            qs = qs.filter(
-                registration__subject_id=self.id,
-                registration__approved__isnull=False,
-            )
-        return qs.exclude(registration__canceled__date__lt=d)
-
-    @cached_property
-    def all_approved_participants(self):
-        qs = SubjectRegistrationParticipant.objects
-        if self.subject_type.subject_type == SubjectType.COURSE:
-            qs = qs.filter(registration__courseregistration__course_history__course_id=self.id,).annotate(
-                approved=models.F("registration__approved"),
-                canceled=models.F("registration__canceled"),
-            )
-        else:  # self.subject_type.subject_type in (SubjectType.EVENT, SubjectType.ORDERABLE):
-            qs = qs.filter(
-                registration__subject_id=self.id,
-                registration__approved__isnull=False,
-            )
-        return list(qs)
-
     @property
     def registration_allowed(self):
         now = timezone.now()
@@ -687,13 +653,6 @@ class Subject(PdfExportAndMailMixin, models.Model):
     def all_approved_registrations(self):
         return list(self.approved_registrations.all())
 
-    @cached_property
-    def all_journal_periods(self):
-        if self.subject_type.subject_type == self.subject_type.COURSE:
-            return [JournalPeriod(self.course, period) for period in self.course.all_periods]
-        else:
-            return [JournalPeriod(self.event)]
-
     @property
     def unapproved_registrations(self):
         return self.active_registrations.filter(approved=None)
@@ -714,6 +673,10 @@ class Subject(PdfExportAndMailMixin, models.Model):
     def all_inactive_registrations(self):
         return list(self.inactive_registrations.all())
 
+    @cached_property
+    def all_journals(self):
+        return list(self.journals.all())
+
     @cached_property
     def all_registration_agreements(self):
         return sorted(
@@ -726,69 +689,14 @@ class Subject(PdfExportAndMailMixin, models.Model):
         )
 
 
-class JournalPeriod:
-    def __init__(self, subject, period=None):
-        self.subject = subject
-        self.period = period
+class SubjectTime(AbstractTime):
+    subject = models.ForeignKey(Subject, on_delete=models.CASCADE, related_name="times", verbose_name=_("course"))
 
-    @property
-    def all_journal_entries(self):
-        qs = self.subject.journal_entries.all()
-        if self.period:
-            if self.period != self.subject.all_periods[0]:
-                qs = qs.filter(date__gte=self.period.start)
-            if self.period != self.subject.all_periods[-1]:
-                qs = qs.filter(date__lte=self.period.end)
-        return list(qs)
-
-    @cached_property
-    def all_approved_participants(self):
-        if self.period:  # course
-            return [
-                participant
-                for participant in self.subject.all_approved_participants
-                if (
-                    participant.approved.date() <= self.period.end
-                    and (participant.canceled is None or participant.canceled.date() >= self.period.start)
-                )
-            ]
-        else:  # event
-            return self.subject.all_approved_participants
-
-    @cached_property
-    def all_alternates(self):
-        alternates = set()
-        for entry in self.all_journal_entries:
-            for alternate in entry.all_alternates:
-                alternates.add(alternate)
-        return list(alternates)
-
-    PresenceRecord = namedtuple("PresenceRecord", ("person", "presences"))
-
-    def get_participant_presences(self):
-        return [
-            self.PresenceRecord(
-                participant, [participant.id in entry.all_participants_idset for entry in self.all_journal_entries]
-            )
-            for participant in self.all_approved_participants
-        ]
-
-    def get_leader_presences(self):
-        return [
-            self.PresenceRecord(
-                leader, [entry.all_leader_entries_by_leader.get(leader, None) for entry in self.all_journal_entries]
-            )
-            for leader in self.subject.all_leaders
-        ]
-
-    def get_alternate_presences(self):
-        return [
-            self.PresenceRecord(
-                alternate,
-                [entry.all_leader_entries_by_leader.get(alternate, None) for entry in self.all_journal_entries],
-            )
-            for alternate in self.all_alternates
-        ]
+    class Meta:
+        app_label = "leprikon"
+        ordering = ("day_of_week", "start")
+        verbose_name = _("time")
+        verbose_name_plural = _("times")
 
 
 class SubjectVariant(models.Model):
@@ -1007,8 +915,8 @@ class SubjectRegistration(PdfExportAndMailMixin, models.Model):
         return list(self.discounts.all())
 
     @cached_property
-    def all_payments(self):
-        return list(self.payments.all())
+    def all_received_payments(self):
+        return list(self.received_payments.all())
 
     @cached_property
     def all_returned_payments(self):
@@ -1130,11 +1038,11 @@ class SubjectRegistration(PdfExportAndMailMixin, models.Model):
         else:
             return self.all_discounts
 
-    def get_payments(self, d):
+    def get_received_payments(self, d):
         if d:
-            return [p for p in self.all_payments if p.accounted.date() <= d]
+            return [p for p in self.all_received_payments if p.accounted.date() <= d]
         else:
-            return self.all_payments
+            return self.all_received_payments
 
     def get_returned_payments(self, d):
         if d:
@@ -1150,8 +1058,11 @@ class SubjectRegistration(PdfExportAndMailMixin, models.Model):
     def get_discounted(self, d=None):
         return sum(p.amount for p in self.get_discounts(d))
 
-    def get_paid(self, d=None):
-        return sum(p.amount for p in self.get_payments(d)) - sum(r.amount for r in self.get_returned_payments(d))
+    def get_received(self, d=None):
+        return sum(p.amount for p in self.get_received_payments(d))
+
+    def get_returned(self, d=None):
+        return sum(r.amount for r in self.get_returned_payments(d))
 
     def get_qr_code(self):
         output = BytesIO()
@@ -1183,6 +1094,10 @@ class SubjectRegistration(PdfExportAndMailMixin, models.Model):
             self.send_mail("approved")
             if not self.payment_requested:
                 self.request_payment(approved_by)
+            if len(self.subject.all_journals) == 1:
+                journal = self.subject.all_journals[0]
+                for participant in self.all_participants:
+                    journal.participants.add(participant)
         else:
             raise ValidationError(
                 (
@@ -1211,6 +1126,24 @@ class SubjectRegistration(PdfExportAndMailMixin, models.Model):
             self.save()
             self.send_mail("refund_offer")
 
+    @transaction.atomic
+    def generate_refund_request(self, generated_by):
+        from .refundrequest import RefundRequest
+
+        if not self.payment_status.overpaid:
+            return
+        remote_accounts = list(
+            self.received_payments.annotate(
+                account=models.F("bankreader_transaction__remote_account_number")
+            ).values_list("account", flat=True)
+        )
+        if len(remote_accounts) == 1 and remote_accounts[0]:
+            RefundRequest.objects.create(
+                registration=self,
+                requested_by=generated_by,
+                bank_account=BankAccount(remote_accounts[0]),
+            )
+
     def refuse(self, refused_by):
         if self.approved is None:
             if self.canceled is None:
@@ -1432,6 +1365,19 @@ class SubjectRegistrationParticipant(SchoolMixin, PersonMixin, QuestionsMixin, m
         #     recipients.add(self.email)
         # return recipients
 
+    PresenceRecord = namedtuple("PresenceRecord", ("entry", "present"))
+
+    @property
+    def presences(self):
+        from .journals import JournalEntry
+
+        present_entry_ids = set(self.journal_entries.values_list("id", flat=True))
+
+        return [
+            self.PresenceRecord(entry, entry.id in present_entry_ids)
+            for entry in JournalEntry.objects.filter(journal__participants=self)
+        ]
+
     def save(self, *args, **kwargs):
         if not self.has_parent1:
             if self.has_parent2:
